pub struct InputField { /* private fields */ }Expand description
Represents a user input field.
Implementations
Sourceimpl InputField
impl InputField
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new InputField.
Creates a new hidden InputField.
Sourcepub fn create<'c, C: Into<Cow<'c, str>>>(title: C) -> Self
pub fn create<'c, C: Into<Cow<'c, str>>>(title: C) -> Self
Creates a new InputField with the provided title.
Creates a new InputField with the provided title.
Sourcepub fn cursor_position(&self, index: usize) -> Position
pub fn cursor_position(&self, index: usize) -> Position
Gets the cursor position of the input field, based on it’s index in a list.
Sourcepub async fn run(
&mut self,
terminal: &mut DefaultTerminal,
events: &mut EventHandler,
) -> Result<String>
pub async fn run( &mut self, terminal: &mut DefaultTerminal, events: &mut EventHandler, ) -> Result<String>
Runs an event loop for the InputField.
Sourcepub fn as_widget(&self) -> Paragraph<'_>
pub fn as_widget(&self) -> Paragraph<'_>
Converts the InputField into a TUI widget.
Sourcepub fn constraint(&self) -> Constraint
pub fn constraint(&self) -> Constraint
Gets the layout constraint required to render the InputField.
Sourceimpl InputField
impl InputField
Sourcepub fn input(&self) -> &str
pub fn input(&self) -> &str
Gets the InputField input.
Sourcepub fn with_input<'a, C: Into<Cow<'a, str>>>(self, val: C) -> Self
pub fn with_input<'a, C: Into<Cow<'a, str>>>(self, val: C) -> Self
Builder function that sets the InputField input.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Gets the InputField title.
Sourcepub fn with_title<'a, C: Into<Cow<'a, str>>>(self, val: C) -> Self
pub fn with_title<'a, C: Into<Cow<'a, str>>>(self, val: C) -> Self
Builder function that sets the InputField title.
Sourceimpl InputField
impl InputField
Sourcepub fn state(&self) -> &InputState
pub fn state(&self) -> &InputState
Gets the InputField state.
Sourcepub fn set_state(&mut self, val: InputState)
pub fn set_state(&mut self, val: InputState)
Sets the InputField state.
Sourcepub fn with_state(self, val: InputState) -> Self
pub fn with_state(self, val: InputState) -> Self
Builder function that sets the InputField state.